@@ -149,13 +149,13 @@ public:
          * should be highlighted.
          */
         HighlightScrolledLines,
-        /** (bool) Specifies whether the terminal will enable Bidirectional
-         * text display
-         */
-        ReflowLines,
         /** (bool) Specifies whether the terminal will enable Reflow of
          * lines when terminal resizes.
          */
+        ReflowLines,
+        /** (bool) Specifies whether the terminal will enable Bidirectional
+         * text display
+         */
         BidiRenderingEnabled,
         /** (bool) Specifies whether text in terminal displays is allowed
          * to blink.
@@ -345,6 +345,9 @@ public:
          *  when hovered by the mouse pointer.
          */
         ColorFilterEnabled,
+
+        /** (bool) Allows mouse tracking */
+        AllowMouseTracking
     };
 
     Q_ENUM(Property)
